@@ -4,5 +4,5 @@ import usefulltools.file as file
 class Math(math.Math):
   pass
 
-class File(file.File)
+class File(file.File):
   pass
\ No newline at end of file
